Book Analytics Dashboard
=======================

## How can the Book Analytics Dashboard help me?
Whether you’re a publisher, librarian, funder, administrator, or other stakeholder in the scholarly communications community, the Dashboard can help you gain a fuller view of book usage data.

Books are made available through a multitude of different platforms, and each has its own way of providing usage statistics. Using our Dashboard gives you a single point of synthesis of usage data from a wide range of [sources](dashboard_data.md), allowing you a consolidated view of usage. 

We take care to bring together a synthesis of usage data of known provenance to allow you to compare data across your chosen time span. Learn more about how we collect and [process book usage data](how_works.md).

## Who’s behind the Dashboard and how is it operated?
The Dashboard was initially developed as a [pilot project 2020-2022](https://digital.library.unt.edu/ark:/67531/metadc1596980/), which developed a prototype for gathering book usage information from multiple data sources, and combining and presenting it in interactive visualisation dashboards for publisher partners.

Funded again by the [Mellon Foundation](https://mellon.org/), the pilot project was scaled up to become the [Book Analytics Dashboard project (2022-2025)](https://doi.org/10.5281/zenodo.7894603), focused on creating a sustainable OA book focused analytics service. 

The fully-functional Dashboard is now operated by [OAPEN](https://www.oapen.org/), a trusted infrastructure for OA books. OAPEN is a not-for-profit organisation which [cannot be sold](https://oapen.hypotheses.org/621), and has committed to the [Principles of Open Scholarly Infrastructure (POSI)](https://doi.org/10.24343/C34W2H) with a [public self-audit](https://oapen.hypotheses.org/524) of their practices across the themes of governance, sustainability, and insurance. OAPEN was chosen as the host organisation by the Book Analytics Dashboard (BAD) project Advisory Board, following a series of focus groups with publishers which endorsed OAPEN as an organisation which could be trusted by the community to run the Dashboard in an open and consultative way.

Community voices are an essential part of the governance strategy for the BAD project. We want to ensure that effective channels are available for feedback, feature requests, praise, and suggestions for improvement; and that these are regularly reviewed and connected to our development planning. During Q3 and Q4 2023, we will be working directly with Dashboard partners to imagine, design, and implement community engagement processes that will allow easy communication and proactive connectivity between the BAD project team and community members.

